#!/bin/sh

#--------------------------------------------------------------------------
# Test configuration.  Following parameter values need to be changed as required by local system setup.
#--------------------------------------------------------------------------

# location of tcl test scripts.  defaults to current directory
LIB="/public_html/net/tcptesting"
# corresponding web url
URL="/net/tcptesting"
# command to run ns
NS="ns ${LIB}/runtest.tcl"
# command to run gnuplot (if plotting is needed)
GNUPLOT="gnuplot"
#format to generate plots in (must be compatible with gnuplot)
TERM="png"
EXT="png"; # file extension to use
#set this to 0 if using standard ns, 1 if using David Wei's ns Linux patch (which implements many high speed TCP algorithms)
NSLINUX=0
#--------------------------------------------------------------------------
# define grid of network conditions to runs tests over.  values are from ToN paper, but are user adjustable.
#--------------------------------------------------------------------------

# user specified congestion control algorithm to test - alphaopt parameter from ns (values defined in opencwnd() function in tcp.cc)
# NOTE: if NSLINUX=1, then instead have options "reno", "cubic", "htcp" etc
if [ $NSLINUX -eq 0 ]; then 
   ALPHAOPT=1 ; # standard ns alphaopt
else
   ALPHAOPT="reno"
fi
CCDESCRIPTION="Standard TCP(NS)" ; # used to label results

if [ $NSLINUX -eq 0 ]; then
   ALPHASTD=1 ; # standard TCP (used for friendliness tests)
else
   ALPHASTD="reno"
fi

# bottleneck link bandwidths to test, in Mb/s ...
BW="10 250 1"	

# rtt's to test, in milliseconds (these values are the two-way propagation delay) ...
RTTLONG="16 40 80 160 200"
RTTSHORT="16 40 80 160"
# rtt of flow 1 in tests where flows have different rtts
RTT1=160

# range of buffer sizes to test, as fraction of BDP ...
QMAXLONG="0.01 0.02 0.05 0.1 0.2 0.4 0.6 0.8 1.0 2.0"; # full range of test cases
QMAXSHORT="0.2 1.0"; # abbreviated set of cases 

# number of background web sessions to test ...
WEBLONG="0 10 25 50"; # full range of test cases
WEBSHORT="0 5"; # abbreviated set of cases
# Define web traffic parameters ...
SCALE="1"  ; # mean request size in packets
LAMBDA="1"  ; # mean idle time in seconds between requests
NUMCLIENTS="1" ; # number of web client/server pairs to use (sessions are spread evenly among these)

# duration of each test (in seconds) ...
TIME=600

# start time for collection "asymptotic" stats
ASYM=400

# delay before first flow starts (non-zero to allow web traffic generator transients to settle down) ...
STAGGER1=100

# delay before second flow starts (so start time is STAGGER1+STAGGER2) ...
STAGGER2=100

# number of times to run each test. A number larger than 1 allows stats (mean and error bars) to be collected
MAXITER=3

